@@ -7,18 +7,21 @@ import http3
 import pandas as pd
 import asyncio
 import rich
+from rich.console import Console
 from datetime import date
 from dataclasses import dataclass
 from bs4 import BeautifulSoup as bs
 from pathlib import Path
 sys.path.append(Path(__file__).parent.parent.as_posix()) # https://stackoverflow.com/questions/16981921
 from phdseeker.rich_dataframe import prettify
+from phdseeker.constants import __version__
 
 # Turns off some warnings
 import urllib3
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
+console = Console()
 
 @dataclass
 class Config:
@@ -99,18 +102,19 @@ class PhDSeeker:
         self.countries = []
         self.dates = []
         self.links = []
-        self.maxpage = maxpage + 1
-        self.file_name = f"PhD_Positions_{date.today()}"
+        self.maxpage = maxpage
+        self.file_name = f"PhD_Positions_{date.today()}[{keywords}]"
         self.df = None # DataFrame of found positions
         self.sought_number = 0
         self.loop = asyncio.get_event_loop()
 
     def __str__(self):
         if self.sought_number:
-            s = ('=' * 80 + '\n#') + 'Sought Ph.D. Positions'.center(78) + (
-                '#\n' + '=' * 80 + '\n')
+            s = 's' if self.maxpage > 1 else ''
+            caption = "│" + f'Out of {self.sought_number} found Ph.D. positions, {len(self.df)} have been fetched in {self.maxpage} page{s}.'.center(console.width-2) + (
+                '│\n└' + '─' * (console.width-2) + '┘\n')
             prettify(self.df[['Country', 'Date', 'Title']], clear_console=False)
-            return ''#s + self.df.to_csv(index=False)
+            return f'{caption}'
 
     async def __get_page__(self, repo, page):
         headers = {
@@ -132,7 +136,6 @@ class PhDSeeker:
                         headers=headers,
                         **keywords,
                         )
-            # print(' '*70+str(type(client)))
             if isinstance(client, http3.client.AsyncClient):
                 await client.close()
             if isinstance(client, httpx._client.AsyncClient):
@@ -143,12 +146,11 @@ class PhDSeeker:
                     foundPositions = int(re.search('(\d+[,\d*]*)', n.text)[1].replace(',',''))
                     self.sought_number += foundPositions
                 try:
-                    sn = f"<< {foundPositions} positions found >>"
+                    sn = f">> {foundPositions} positions found <<"
                 except:
-                    sn = f"<< No positions found >>"
+                    sn = ">> No positions found <<"
                 print(
-                    # f"\r[[ {self.sought_number} positions found ]] {' '*(55-len(self.keywords))}"
-                    f"\r {sn.center(80)}"
+                    f"\r{sn.center(console.width)}"
                 )
             titles, countries, dates, links = [
                 soup.select(item) if repo == 'scholarshipdb' else
@@ -172,13 +174,13 @@ class PhDSeeker:
         except AssertionError:
             return False # break
         except Exception as e:
-            print(e)
+            # print(e)
             return False # break
 
     async def prepare(self):
         for repo in self.repos:
-            print(f"\r{('::[ '+repo+' ]::').center(80, '=')}")
-            tasks = [asyncio.create_task(self.__get_page__(repo, page)) for page in range(1, self.maxpage)]
+            print(f"\r{('::[ '+repo+' ]::').center(console.width, '=')}")
+            tasks = [asyncio.create_task(self.__get_page__(repo, page)) for page in range(1, self.maxpage+1)]
             try:
                 await asyncio.wait(tasks, return_when=asyncio.FIRST_EXCEPTION)
             except Exception:
@@ -213,7 +215,9 @@ class PhDSeeker:
         """Creates excel/csv files based on all revceived data"""
         df = self.positions
         if self.sought_number:
-            rich.print(f"\n{self.sought_number} positions have been found in total.")
+            s  = 's' if output=='both' else ''
+            print(f"\r{console.width*' '}\n>>>> {self.sought_number} positions have been found in total.",
+            f"Specifically, {len(df)} records of them have been saved in the following file{s}:" , sep='\n')
             if output in ('csv', 'both'):
                 df.to_csv(f'{self.file_name}.csv', index=False)
                 rich.print(f'[blue]{self.file_name}.csv saved![/blue]')
@@ -221,8 +225,16 @@ class PhDSeeker:
                 df.to_excel(f'{self.file_name}.xlsx', index=False)
                 rich.print(f'[blue]{self.file_name}.xlsx saved![/blue]')
         else:
-            rich.print('[blink][red] >>> No positions found, change your keyword. <<< [/red][/blink]')
+            rich.print('[red blink] >>> No positions found, change your keyword. <<< [/red blink]')
 
+def checkNewVersion(output:dict):
+    url = 'https://raw.github.com/Aghababaei/PhD-Seeker/master/phdseeker/constants.py'
+    response = httpx.get(url)
+    url_version = re.search('(__version__ = "(\d\.\d(\.\d+)?)")', response.text, re.M)[2]
+    version = lambda v: list(map(int, v.split('.')))
+    if version(url_version) > version(__version__):
+        message = '[blink]New version ([green]{}[/green]) is available![/blink] Use `pip install --upgrade phdseeker` to update'
+        output['message'] = message.format(url_version)
 
 def main():
     # Comma seperated list of keywords for the field of desired PhD career + presets
